<?php defined('SYSPATH') or die('No direct script access.');

class Model_Students extends Model
{
    /** @return Model_Student[] */
    public static function ofDiscipline(Model_Discipline $discipline) {
        $sql = 'CALL `GetStudentsForDiscipline`(:id)';
        $result = DB::query(Database::SELECT, $sql)
            ->param(':id', $discipline->ID)
            ->execute();

        $list = [];
        foreach ($result as $row)
            $list[] = new Model_Student($row);
        return $list;
    }

    /**
     * @param $group int group id
     * @return Database_Result
     */
    public static function ofGroup($group, $semesterID = null) {
        $semesterID = $semesterID ? $semesterID : User::instance()->SemesterID;

        $sql = 'CALL `GetStudents`(:group, $semester)';
        return DB::query(Database::SELECT, $sql)
            ->param(':semester', $semesterID)
            ->param(':group', $group)
            ->execute();
    }

    public static function getGradeID($gradeNum, $degree) {
        $degree = Database::instance()->escape($degree);
        $sql = 'SELECT `GetGradeID`(:gradeNum, :degree) AS `ID`';
        return DB::query(Database::SELECT, $sql)
            ->param(':grade', $gradeNum)
            ->param(':degree', $degree)
            ->execute()->get('ID');
    }

    public static function search($gradeID, $groupID, $facultyID, $name, $disciplineID) {
        $sql = 'CALL `SearchStudents`(:grade, :group, :faculty, :name, :discipline)';
        return DB::query(Database::SELECT, $sql)
            ->parameters([
                ':name'       => $name,
                ':faculty'    => (int) $facultyID,
                ':grade'      => (int) $gradeID,
                ':group'      => (int) $groupID,
                ':discipline' => (int) $disciplineID,
            ])->execute()->as_array();
    }

    public static function searchStudentsByName($name, $facultyID = null, $gradeID = null, $groupID = null, $semesterID = null) {
        $semesterID = $semesterID ? $semesterID : User::instance()->SemesterID;

        $sql = 'CALL `SearchStudentsByName`(:name, :faculty, :grade, :group, :semester)';
        return DB::query(Database::SELECT, $sql)
            ->parameters([
                ':name'     => $name,
                ':faculty'  => (int) $facultyID,
                ':grade'    => (int) $gradeID,
                ':group'    => (int) $groupID,
                ':semester' => (int) $semesterID,
            ])->execute()->as_array();
    }
}